==> org-lsst-ccs-subsystem-fcs-main-2.0.1-sources.jar: org/lsst/ccs/subsystems/fcs/FilterClampXminusModule.java <==
/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package org.lsst.ccs.subsystems.fcs;

import org.lsst.ccs.subsystems.fcs.common.Thermometer;
import org.lsst.ccs.subsystems.fcs.FcsEnumerations.FilterClampState;

/**
 *
 * @author virieux
 */
public class FilterClampXminusModule extends FilterClampModule {

    public FilterClampXminusModule(String aName, int aTickMillis, 
            Sensor14bits filterPresenceSensor, 
            Sensor14bits lockSensor, 
            Thermometer thermometer, 
            int filterPositionValueA, 
            int filterPositionValueB, 
            int filterPositionValueC, 
            int filterPositionOffset, 
            int lockSensorValueA, 
            int lockSensorValueB, 
            int lockSensorValueC, 
            int lockSensorOffset, 
            int timeoutForUnlocking, 
            int timeoutForReleasing,
            int currentToUnlock,
            int currentToMaintainUnlocked) {
        super(aName, aTickMillis, filterPresenceSensor, lockSensor, thermometer, 
                filterPositionValueA, filterPositionValueB, filterPositionValueC, 
                filterPositionOffset, 
                lockSensorValueA, lockSensorValueB, lockSensorValueC, 
                lockSensorOffset, timeoutForUnlocking, timeoutForReleasing,
                currentToUnlock, currentToMaintainUnlocked );
    }



    



    

    @Override
    public FilterClampState computeClampState() {
        
        FilterClampState state = super.computeClampState();
        if (state.equals(FilterClampState.UNCLAMPEDEMPTY) && this.getActuator().isOff()) {
            return FilterClampState.READYTOCLAMP;
        } else {
            return state;
        }
    }
    
}

==> org-lsst-ccs-subsystem-fcs-main-2.0.1.1-sources.jar: org/lsst/ccs/subsystems/fcs/FilterClampXminusModule.java <==
/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package org.lsst.ccs.subsystems.fcs;

import org.lsst.ccs.subsystems.fcs.common.Thermometer;
import org.lsst.ccs.subsystems.fcs.FcsEnumerations.FilterClampState;

/**
 *
 * @author virieux
 */
public class FilterClampXminusModule extends CarouselClampModule {

    public FilterClampXminusModule(String aName, int aTickMillis, 
            Sensor14bits filterPresenceSensor, 
            Sensor14bits lockSensor, 
            Thermometer thermometer, 
            int filterPositionValueA, 
            int filterPositionValueB, 
            int filterPositionValueC, 
            int filterPositionOffset, 
            int lockSensorValueA, 
            int lockSensorValueB, 
            int lockSensorValueC, 
            int lockSensorOffset, 
            int timeoutForUnlocking, 
            int timeoutForReleasing,
            int currentToUnlock,
            int currentToMaintainUnlocked) {
        super(aName, aTickMillis, filterPresenceSensor, lockSensor, thermometer, 
                filterPositionValueA, filterPositionValueB, filterPositionValueC, 
                filterPositionOffset, 
                lockSensorValueA, lockSensorValueB, lockSensorValueC, 
                lockSensorOffset, timeoutForUnlocking, timeoutForReleasing,
                currentToUnlock, currentToMaintainUnlocked );
    }



    



    

    @Override
    public FilterClampState computeClampState() {
        
        FilterClampState state = super.computeClampState();
        if (state.equals(FilterClampState.UNCLAMPEDEMPTY) && this.getActuator().isOff()) {
            return FilterClampState.READYTOCLAMP;
        } else {
            return state;
        }
    }
    
}
